<?php
  /*
    Steptail Photo Expo 
    
    Extremely simplistic gallery software that requires minimum administration.
        
    Important Notice: 
    To configure this program, see settings.php. Manual is yet to be written. For
    quick usage information or technical enquiries, contact the lead programmer at 
    oliver@dlc.fi.
    
    Includes portions of code written by Evan Hunter (evan@ozhiker.com, image metadata),
    and Jeroen Wijering (mail@jeroenwijering.com, .FLV player).
        
    USAGE 
      Simply
        http://www.example.com/path/to/gallery/
      Or alternatively
        http://www.example.com/path/to/gallery/index.php?g=galleryname
          This will then search for a gallery and a directory called "galleryname",
          under $media_dir, that has been specified in settings.php

    VERSION HISTORY
      v0.8.1   12/05/2006      Software will parse directory name for ordering and
                               description information as such: 
                               "/200504_April 2005_Photos from April"
      v0.8.0   12/05/2006      Added support for a list of galleries. 
      v0.7.0   23/04/2006      Almost half of the code re-written, added support for
                               indexing photos. 
      v0.6.2   23/04/2006      Added a possibility to include a Copyright notice
                               in the page on bottom 
      v0.6.1   22/04/2006      Now reads and displays IPTC information from image. 
                               Photoshop creates IPTC -tags for Copyright and Caption.
      v0.6.0   22/04/2006      Added .FLV player support, fixed some cometic issues;
                               for example, now the gallery doesn't attempt to display
                               Camera Settings -pane, when there's no EXIF information
                               present.
      v0.5.1   18/04/2006      Initial fully working release
  
    PARAMETERS
      $m   =   Mode (optional). Can be 
           i     Index (show index of galleries)
           g     Gallery (show index of pictures in gallery) (not implemented)
           s     Show (show image)
      $g   =   Gallery, what gallery should be shown? (optional)
      $i   =   Image index (optional), which image should be shown?
    
    LICENSING
      The gallery script package is licensed under the Creative Commons Attribution
      License. You are free to use, redistribute and modify the program and use it 
      non-commercially provided that you credit me as the author. See 
      http://creativecommons.org/licenses/by-nc-sa/2.5/ for more information on this
      license. Other scripts that aren't written by the gallery author are licensed 
      under their respective owners. See ./plugins/flv/readme.txt and 
      ./metadata/COPYING.txt
  */
  
  // COMPULSORY INCLUDE FILES
  // Include settings from a separate file
  include_once("settings.php");

  // Include the PHP JPEG Metadata Toolkit by Evan Hunter
  include_once("metadata/JPEG.php");
  include_once("metadata/JFIF.php");
  include_once("metadata/PictureInfo.php");
  include_once("metadata/XMP.php");
  include_once("metadata/Photoshop_IRB.php");
  include_once("metadata/EXIF.php");

  // CHECK IF $m MODE IS SPECIFIED
  if (!$m) {
    // fallback; no mode is specified: 
    // check if the gallery ($g) variable is set
    if ($g) {
      // gallery is specified, no need for $m, we already
      // know that the gallery to be viewed is $g
      $m = 's';
    } else {
      // otherwise show us an index of all galleries
      $m = 'i';
    }
  }
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" 
"http://www.w3.org/TR/html4/loose.dtd">
<html>
  <head>
    <title><?php printf($page_title) ?></title>
    <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
    <link rel="stylesheet" type="text/css" href="style.css">
  </head>
  <body>
    <!-- Begin of Contents -->
<?php
  // Display header image
  headerimage();
  // Display header text
  headertext();

  // Which mode specified?
  switch ($m) {
  case 'i':
    /*********************************************************************/
    /* $m = 'i'                                                          */
    /* Show us an index of all galleries available                       */
    /*                                                                   */
    /*********************************************************************/
    // printf("<br><strong>Error: This action hasn't been implemented yet.</strong>");
    // Get the list of galleries
    $glist = arraygalleries($media_dir . "/");
    $gtotal = count($glist);
    // ... and sort them:
    natcasesort($glist);
    // change array numbering to 0,1,2,3,4 instead of eg. 4,1,3,2,0
    $glist = array_values($glist);    
    printf("<table width=\"580\" border=\"0\" align=\"center\" cellpadding=\"5\" cellspacing=\"1\" bgcolor=\"#D0D0D0\">\n");
//  print column explanations on the table created
    printf("<tr><td bgcolor=\"#8F8FFF\"><span class=\"gallerycolumnhelp\">Gallery Name</span>\n</td>\n<td bgcolor=\"#8F8FFF\"><span class=\"gallerycolumnhelp\">Description</span>\n</td>\n</tr>\n");
//  list all galleries
    for($i=0;$i<$gtotal;$i++) {
      // select appropriate gray background level for the list to make it more clear
      if ($grayselect == "#DFDFDF")
        $grayselect = "#E9E9E9";
      else
        $grayselect = "#DFDFDF";

      printf("  <tr>\n");
      // assign gallery name and gallery description from directory name
      $gname = ""; $gdesc = "";
      list(, $gname, $gdesc) = explode("_", $glist[$i], 3);
      if (!$gname)
        $gname = $glist[$i];
      if (!$gdesc)
        $gdesc = "no description";
        
      listgalleries($gname, $gdesc, "?m=s&g=" . $glist[$i], $grayselect);
      printf("  </tr>\n");
    }
    printf("<tr>\n<td colspan=\"2\" align=\"right\" bgcolor=\"#FFFFFF\"><span class=\"photoinfoname\">Total: </span><span class=\"photoinfodata\">" . $gtotal . "</span>\n</td></tr>");
    printf("</table>\n");
    printf("\n");
    break;
  case 'g':
    /*********************************************************************/
    /* $m = 'g'                                                          */
    /* Show us an index of all photos or elements available in a gallery */
    /*                                                                   */
    /*********************************************************************/
    // Check if gallery exists
    printf("<br><strong>Notice: Photo and media listing in a gallery is not supported yet in this version</strong><br>");
    if (!file_exists($media_dir . $g)) {
      printf("<strong>Error: media path <em>" . $media_dir . $g . "</em> doesn't exist. The requested gallery name may be wrong, or a variable in settings.php isn't set properly. Please check settings.php to see that \$media_dir is correct.</strong>");
      endhtml();
      exit();
    }
    // Get the list of files...
    $flist = listfiles($media_dir . $g . "/");
    $ftotal = count($flist);
    // ... and sort them:
    natcasesort($flist);
    // change array numbering to 0,1,2,3,4 instead of eg. 4,1,3,2,0
    $flist = array_values($flist);    
    // Display table of images contained inside a gallery
    printf ("      <table border=\"0\" align=\"center\" cellpadding=\"4\" cellspacing=\"1\" bgcolor=\"#D0D0D0\">\n");
    foreach ($flist as $currentfile) {
      // display gallery contents
      gallerycontents();
    }
    printf ("      </table>\n");
    break;
  case 's':
    /*********************************************************************/
    /* $m = 's'                                                          */
    /* Just show us a photo or other element                             */
    /*                                                                   */
    /*********************************************************************/
    // Check if gallery exists
    if (!file_exists($media_dir . $g)) {
      printf("<strong>Error: media path <em>" . $media_dir . $g . "</em> doesn't exist. The requested gallery name may be wrong, or a variable in settings.php isn't set properly. Please check settings.php to see that \$media_dir is correct.</strong>");
      endhtml();
      exit();
    }
    // Get the list of files...
    $flist = listfiles($media_dir . $g . "/");
    $ftotal = count($flist);
    // ... and sort them:
    natcasesort($flist);
    // change array numbering to 0,1,2,3,4 instead of eg. 4,1,3,2,0
    $flist = array_values($flist);    
    // if no image index value ($i) is specified, default to zero.
    if (!$i) {
      $i = '0';
    }
    // For element.php to work, it also needs other variables, that need
    // to be known, so that it can display the proper media file. Here, we
    // just supply these "other" variables, $n and $e. $n as in fileName and
    // $e as in Extension. pathinfo() will look into the directory path, and 
    // break it down to an array.
    $finfo = pathinfo($media_dir . $g . "/" . $flist[$i]);
    $n = basename($finfo['basename'], '.' . $finfo['extension']);
    $e = $finfo['extension'];
    // Display media file
    include_once("element.php");
    break;
  default:
    // reached when an invalid $m is specified
    printf("<strong>Error: mode <em>" . $m . "</em> doesn't exist.</strong>");
  }
?>
<?php endhtml() ?>
<?php
  /****************************/
  /*     DEFINE FUNCTIONS     */
  /****************************/
  function gallerycontents() {
  // Works in association with the code that calls this function to
  // create a nice little list of images contained in a gallery.
    global $currentfile;
    printf ("        <tr>\n");
    printf ("          <td bgcolor=\"#FFFFFF\">\n");
    printf ("            <div class=\"photoinfodata\"><a href=\"linkki\">");
    printf ($currentfile . "</a></div><br>\n");
    printf ("            <div class=\"photodescription\">");
    printf ("description" . "</div>\n");
    printf ("          </td>\n");
    printf ("        </tr>\n");
  }
  function listfiles($dirname=".") {
    // Lists files in directory and returns them in an array according to extensions array
    // specified in $media_support.
    global $media_supported;
    $ext = $media_supported;
    $files = array();
    if($handle = opendir($dirname)) {
      while(false !== ($file = readdir($handle)))
        for($i=0;$i<sizeof($ext);$i++)
          if(strstr(strtolower($file), ".".$ext[$i]))
            $files[] = $file;
      closedir($handle);
    }
    return($files);
  }
  function arraygalleries($dirname=".") {
    // Lists files in directory and returns them in an array according to extensions array
    // specified in $media_support.
//    $ext = '';
    $galleries = array();
    if($handle = opendir($dirname)) {
      while(false !== ($file = readdir($handle))) {
        if (filetype($dirname . $file) == 'dir') {
          if ($file !== ".") 
            if ($file !== "..")
              $galleries[] = $file;
        }
        //for($i=0;$i<sizeof($ext);$i++)
        //  if(strstr(strtolower($file), ".".$ext[$i]))
        //    $files[] = $file;
      }
      closedir($handle);
    }
    return($galleries);
  }
  function listgalleries($galleryname, $gallerytext, $link, $bgcolor) {
    printf("    <td valign=\"top\" nowrap bgcolor=\"" . $bgcolor . "\">\n");
    printf("      <span class=\"galleryname\"><a href=\"" . $link  . "\">" . $galleryname . "</a></span>\n");
    printf("    </td>\n");
    printf("    <td valign=\"top\" bgcolor=\"" . $bgcolor . "\">\n");
    printf("      <span class=\"gallerydescription\">" . $gallerytext . "</span>\n");
    printf("    </td>\n");
  }

  // Write the HTML code necessary to "end" an html-document.
  function endhtml() {
    copyright();
    printf ("\n    <!-- End of Contents -->\n  </body>\n</html>\n");
  }


  // Write the HTML code to display an HEADER IMAGE.
  function headerimage() {
    global $page_headerimage, $page_headerimagealt;
    // Display the header image
    // First check the header image is available
    if ($page_headerimage != '') {
      if (file_exists($page_headerimage)) {
        if ($page_headerimagealt == '') {
          $page_headerimagealt = $page_headerimage;
        }
        printf ("<div align=\"center\">");
        printf ("<img src=\"" . $page_headerimage . "\" alt=\"" . $page_headerimagealt . "\">");
        printf ("</div>\n");
        printf ("<br>\n");
      } else {
        // Header image isn't available
        printf("<strong>Error in Gallery Settings: Header Image file <em>" . $page_headerimage . "</em> doesn't exist.</strong>");
        endhtml();
        exit();
      }
    } 
  } 
  
  
  // Write the HTML code to display HEADER TEXT
  function headertext() {
    global $page_headertext, $page_gallerytext, $g, $m;
    if ($page_headertext != '') {
      printf("<div class=\"heading\">");
      printf($page_headertext);
      printf("</div>");
    }
    if ($page_gallerytext and $g and $m != 'i') {
      printf("<div class=\"heading\">");
      // assign gallery name and gallery description from directory name
      $gname = ""; $gdesc = "";
      list(, $gname, $gdesc) = explode("_", $g, 3);
      if (!$gname)
        $gname = $glist[$i];
      if (!$gdesc)
        $gdesc = "no description";
      printf($gname);
      printf("</div>");
    }
  }
  
  
  // Write the HTML code to display a COPYRIGHT TAG
  function copyright() {
    global $page_copyright;
    // Display Copyright tags.
    if ($page_copyright) {
      printf ("<br>");
      printf ("<div align=\"center\">");
      printf ($page_copyright);
      printf ("</div>");
    }
  }
?>